@@ -62,8 +62,10 @@ __all__ = [
     "ky",
     "kyctapp",
     "la",
+    "lactapp_1",
     "mass",
     "massappct",
+    "massappct_u",
     "masslandct",
     "md",
     "mdag",
