@@ -12,7 +12,7 @@ from juriscraper.opinions.united_states.state import okla
 
 class Site(okla.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         d = date.today()
         self.url = "http://www.oscn.net/applications/oscn/Index.asp?ftdb=STOKCSCR&year={year}&level=1".format(
