@@ -3,14 +3,14 @@ import time
 from datetime import date
 
 from dateutil.rrule import MONTHLY, rrule
-from juriscraper.OpinionSite import OpinionSite
 
 from juriscraper.lib.network_utils import SSLAdapter
+from juriscraper.OpinionSite import OpinionSite
 
 
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.url = "https://www.cadc.uscourts.gov/internet/opinions.nsf/OpinionsByMonday?OpenView&StartKey=20151020150928&Count=2&scode=1"
         self.court_id = self.__module__
         self.back_scrape_iterable = [
