@@ -5,13 +5,13 @@
 # Reviewer: mlr
 # Date created: 18 July 2014
 
-from juriscraper.OralArgumentSite import OralArgumentSite
 from juriscraper.lib.string_utils import convert_date_string
+from juriscraper.OralArgumentSite import OralArgumentSite
 
 
 class Site(OralArgumentSite):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "http://www.ca4.uscourts.gov/oral-argument/listen-to-oral-arguments"
 
